==> ember-ladda-button-1.0.16.tgz: package/addon/components/ladda-button.js <==
import Component from '@ember/component';
import layout from '../templates/components/ladda-button';
import Ember from 'ember';
import * as Ladda from 'ladda';

export default Component.extend({
  laddaButton: Ember.inject.service(),

  // meant to be overriden
  text: '',
  buttonStyle: null,
  spinnerSize: null,
  spinnerColor: null,
  spinnerLines: null,
  inFlight: false,
  action: () => Ember.RSVP.resolve(),

  layout,
  ladda: null,
  tagName: 'button',

  attributeBindings: [
    '_buttonStyle:data-style',
    '_spinnerSize:data-spinner-size',
    '_spinnerColor:data-spinner-color',
    '_spinnerLines:data-spinner-lines',
    'disabled',
    'type'
  ],

  _buttonStyle: Ember.computed.or('buttonStyle', 'laddaButton.buttonStyle'),
  _spinnerSize: Ember.computed.or('spinnerSize', 'laddaButton.spinnerSize'),
  _spinnerColor: Ember.computed.or('spinnerColor', 'laddaButton.spinnerColor'),
  _spinnerLines: Ember.computed.or('spinnerLines', 'laddaButton.spinnerLines'),

  inFlightDidChange: Ember.observer('inFlight', function() {
    this.updateLoadingState();
  }),

  didInsertElement() {
    this._super(...arguments);

    this.set('ladda', Ladda.create(document.getElementById(this.get('elementId'))));

    if (this.get('inFlight')) {
      Ember.run.next(() => {
        this.updateLoadingState();
      });
    }
  },

  updateLoadingState() {
    if (this.get('inFlight')) {
      this.get('ladda').start();
    } else {
      this.get('ladda').stop();
    }
  },

  click() {
    const maybePromise = this.action();
    // duck typing instead of explicitly checking the instance
    // class because it can be a Promise or RSVP.Promise
    if (maybePromise && typeof maybePromise.finally === 'function') {
      this.set('inFlight', true);
      maybePromise.finally(() => {
        if (!this.get('isDestroying') && !this.get('isDestroyed')) {
          this.set('inFlight', false);
        }
      });
    }
  }
});

==> ember-ladda-button-1.0.18.tgz: package/addon/components/ladda-button.js <==
import Component from '@ember/component';
import * as Ladda from 'ladda';
import layout from '../templates/components/ladda-button';
import { inject } from '@ember/service';
import { or } from '@ember/object/computed';
import { resolve } from 'rsvp';

export default Component.extend({
  laddaButton: inject(),

  // meant to be overriden
  action: () => resolve(),
  buttonStyle: null,
  inFlight: false,
  spinnerColor: null,
  spinnerLines: null,
  spinnerSize: null,
  text: '',

  attributeBindings: [
    '_buttonStyle:data-style',
    '_spinnerSize:data-spinner-size',
    '_spinnerColor:data-spinner-color',
    '_spinnerLines:data-spinner-lines',
    'disabled',
    'type'
  ],
  layout,
  tagName: 'button',

  _buttonStyle: or('buttonStyle', 'laddaButton.buttonStyle'),
  _spinnerColor: or('spinnerColor', 'laddaButton.spinnerColor'),
  _spinnerLines: or('spinnerLines', 'laddaButton.spinnerLines'),
  _spinnerSize: or('spinnerSize', 'laddaButton.spinnerSize'),

  ladda: null,

  didInsertElement() {
    this._super(...arguments);

    this.set('ladda', Ladda.create(this.element));

    if (this.get('inFlight')) {
      this.updateLoadingState();
    }
  },

  didUpdateAttrs() {
    this._super(...arguments);

    this.updateLoadingState();
  },

  willDestroy() {
    this.get('ladda').remove();

    this._super(...arguments);
  },

  updateLoadingState() {
    if (this.get('inFlight')) {
      this.get('ladda').start();
    } else {
      this.get('ladda').stop();
    }
  },

  click() {
    const maybePromise = this.action();
    // duck typing instead of explicitly checking the instance
    // class because it can be a Promise or RSVP.Promise
    if (maybePromise && typeof maybePromise.finally === 'function') {
      this.set('inFlight', true);
      this.updateLoadingState();
      maybePromise.finally(() => {
        if (!this.get('isDestroying') && !this.get('isDestroyed')) {
          this.set('inFlight', false);
          this.updateLoadingState();
        }
      });
    }
  }
});
